@@ -1,11 +1,11 @@
-from bfet.create_data import DataCreator
-from bfet.testing_models import DjangoTestingModel
+from .create_data import DataCreator
+from .testing_models import DjangoTestingModel
 
 __author__ = """Lucas Montes"""
 
 __email__ = "lluc23@hotmail.com"
 
-__version__ = "0.1.2"
+__version__ = "0.1.5"
 
 __all__ = [
     "DjangoTestingModel",
